Demo de Transiciones - KardoCSS v1.1.4

## Propiedades de Transición

### 🔍 Scale (Escala)

¡Pasa el cursor!
`hover:k-scale-115`

### 🔄 Rotate (Rotación)

¡Gira!
`hover:k-rotate-15`

### 🎨 Colors (Colores)

¡Cambia!
`hover:k-bg-gradient`

### 👻 Opacity (Opacidad)

¡Desaparece!
`hover:k-opacity-30`

### 💫 Shadow (Sombra)

¡Elévate!
`hover:k-shadow-xl`

### ⚡ Combinado

🚀
`múltiples efectos`

## ⏱️ Duraciones de Transición

⚡
75ms
Ultra Rápido
🏃
300ms
Rápido
🚶
700ms
Moderado
🐌
1000ms
Lento

## 🎯 Botones Interactivos

## 🎴 Tarjetas Interactivas

💎

### Premium

Efecto de elevación suave

🎯

### Pro

Transición perfecta

⭐

### Elite

Hover espectacular

## 🎬 Animaciones Continuas

⚙️

Spin

📍

Ping

💓

Pulse

🏀

Bounce

## 🎉 KardoCSS v1.1.4

Transiciones y animaciones mejoradas para máxima visibilidad

✅ Efectos dramáticos ✅ Colores vibrantes ✅ Fácil de ver